use fish::builtins::fish_key_reader;

fn main() {
    fish_key_reader::main();
}
